:mod:`art.defences.transformer.evasion`
=======================================
.. automodule:: art.defences.transformer.evasion

Defensive Distillation
----------------------
.. autoclass:: DefensiveDistillation
   :members:
   :special-members:
